@@ -229,9 +229,10 @@ public class QueryAction extends RTAction {
             LOG.error("", e);
             RealtimeException re = RealtimeExceptionCodes.STANZA_INTERNAL_SERVER_ERROR.create(e, e.getMessage());
             throw re;
-        } catch (Throwable e) {
-            LOG.error("", e);
-            RealtimeException re = RealtimeExceptionCodes.STANZA_INTERNAL_SERVER_ERROR.create(e, e.getMessage());
+        } catch (Throwable t) {
+            ExceptionUtils.handleThrowable(t);
+            LOG.error("", t);
+            RealtimeException re = RealtimeExceptionCodes.STANZA_INTERNAL_SERVER_ERROR.create(t, t.getMessage());
             throw re;
         } finally {
             sendLock.unlock();
