@@ -49,7 +49,7 @@
 
 package com.openexchange.realtime.json.osgi;
 
-import org.osgi.framework.BundleContext;
+import java.util.concurrent.atomic.AtomicBoolean;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
@@ -80,7 +80,9 @@ import com.openexchange.realtime.json.payload.converter.RealtimeExceptionToJSONC
 import com.openexchange.realtime.json.payload.converter.StackTraceElementToJSONConverter;
 import com.openexchange.realtime.json.payload.converter.ThrowableToJSONConverter;
 import com.openexchange.realtime.json.payload.converter.primitive.ByteToJSONConverter;
+import com.openexchange.realtime.json.payload.converter.primitive.IntegerToJSONConverter;
 import com.openexchange.realtime.json.payload.converter.primitive.JSONToByteConverter;
+import com.openexchange.realtime.json.payload.converter.primitive.JSONToIntegerConverter;
 import com.openexchange.realtime.json.payload.converter.primitive.JSONToStringConverter;
 import com.openexchange.realtime.json.payload.converter.primitive.StringToJSONConverter;
 import com.openexchange.realtime.json.presence.converter.JSONToPresenceStateConverter;
@@ -96,8 +98,9 @@ import com.openexchange.timer.TimerService;
 public class RTJSONActivator extends AJAXModuleActivator {
 
     private static final Logger LOG = LoggerFactory.getLogger(RTJSONActivator.class);
+    private final AtomicBoolean isStopped = new AtomicBoolean(true);
     private RealtimeActions realtimeActions;
-    private RTJSONHandler handler;
+    private volatile RTJSONHandler handler;
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -113,7 +116,8 @@ public class RTJSONActivator extends AJAXModuleActivator {
         ManagementHouseKeeper managementHouseKeeper = ManagementHouseKeeper.getInstance();
         managementHouseKeeper.initialize(this);
 
-        handler = new RTJSONHandler();
+        RTJSONHandler handler = new RTJSONHandler();
+        this.handler = handler;
         registerService(Channel.class, new JSONChannel(handler));
 
         /*
@@ -137,6 +141,8 @@ public class RTJSONActivator extends AJAXModuleActivator {
         registerService(SimplePayloadConverter.class, new RealtimeExceptionToJSONConverter());
         registerService(SimplePayloadConverter.class, new JSONToIDConverter());
         registerService(SimplePayloadConverter.class, new IDToJSONConverter());
+        registerService(SimplePayloadConverter.class, new JSONToIntegerConverter());
+        registerService(SimplePayloadConverter.class, new IntegerToJSONConverter());
 
         // Add Transformers using Converters
         PayloadTreeConverter converter = getService(PayloadTreeConverter.class);
@@ -158,17 +164,51 @@ public class RTJSONActivator extends AJAXModuleActivator {
          * Register all RealtimeJanitor services contained in this bundle
          */
         for(RealtimeJanitor realtimeJanitor : RealtimeJanitors.getInstance().getJanitors()) {
-            registerService(RealtimeJanitor.class, realtimeJanitor);
+            registerService(RealtimeJanitor.class, realtimeJanitor, realtimeJanitor.getServiceProperties());
+        }
+        isStopped.set(false);
+    }
+
+    @Override
+    public void stopBundle() throws Exception {
+        if (isStopped.compareAndSet(false, true)) {
+            ManagementHouseKeeper.getInstance().cleanup();
+            RealtimeJanitors.getInstance().cleanup();
+            RTJSONHandler handler = this.handler;
+            if (null != handler) {
+                handler.shutDownCleanupTimer();
+                this.handler = null;
+            }
+            JSONServiceRegistry.SERVICES.set(null);
+            super.stopBundle();
         }
     }
 
     @Override
-    public void stop(BundleContext context) throws Exception {
-        ManagementHouseKeeper.getInstance().cleanup();
-        RealtimeJanitors.getInstance().cleanup();
-        unregisterService(realtimeActions);
-        JSONServiceRegistry.SERVICES.set(null);
-        super.stop(context);
+    protected void handleAvailability(Class<?> clazz) {
+        if (allAvailable()) {
+            LOG.info("{} regained all needed services {}. Going to restart bundle.", this.getClass().getSimpleName(), clazz.getSimpleName());
+            try {
+                startBundle();
+            } catch (Exception e) {
+                LOG.error("Error while starting bundle.", e);
+            }
+        }
+    }
+
+    @Override
+    protected void handleUnavailability(Class<?> clazz) {
+        if (!isStopped.get()) {
+            LOG.warn(
+                "{} is handling unavailibility of needed service {}. Going to stop bundle.",
+                this.getClass().getSimpleName(),
+                clazz.getSimpleName());
+            try {
+                this.stopBundle();
+            } catch (Exception e) {
+                LOG.error("Error while stopping bundle.", e);
+            }
+        }
     }
 
 }
